=========
Changelog
=========

Version 0.1.5
=============
- Fix factorial, factorial2 scipy import

Version 0.1.4
=============
- Adds spectrum to topography functionality
- Updated documentation and minor fixes

Version 0.1.3
=============
- Fixed error when data has invalids

Version 0.1.2
=============
- Fixed error in interpolator call
- Added documentation to readthedocs

Version 0.1.1
=============

- Corrections and addition to PyPi documentation
- Added example file

Version 0.1
===========

- Initial public pre-alpha release
